﻿using System;
using System.Drawing;
using System.Windows.Forms;
using Telerik.WinControls;
using Telerik.WinControls.UI;

namespace RadGridViewExample
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            for (int i = 0; i < 3; i++)
            {
                this.radGridView1.Columns.Add(new GridViewDecimalColumn("Column " + i));
            }

            for (int i = 0; i < 20; i++)
            {
                this.radGridView1.Rows.Add(i % 13, i % 17, i % 2);
            }

            this.radGridView1.AutoSizeColumnsMode = GridViewAutoSizeColumnsMode.Fill;

            this.radGridView1.GroupSummaryEvaluate += new GroupSummaryEvaluateEventHandler(radGridView1_GroupSummaryEvaluate);
            this.radGridView1.ViewRowFormatting += new RowFormattingEventHandler(radGridView1_ViewRowFormatting);

            GridViewSummaryItem planiranoItemCol0 = new GridViewSummaryItem();
            planiranoItemCol0.Aggregate = GridAggregateFunction.Sum;
            planiranoItemCol0.Name = "Column 0";

            GridViewSummaryItem planiranoItemCol1 = new GridViewSummaryItem();
            planiranoItemCol1.Aggregate = GridAggregateFunction.Sum;
            planiranoItemCol1.Name = "Column 1";

            GridViewSummaryItem planiranoItemCol2 = new GridViewSummaryItem();
            planiranoItemCol2.Aggregate = GridAggregateFunction.Sum;
            planiranoItemCol2.Name = "Column 2";

            GridViewSummaryRowItem planiranoRowItem = new GridViewSummaryRowItem();
            planiranoRowItem.Add(planiranoItemCol0);
            planiranoRowItem.Add(planiranoItemCol1);
            planiranoRowItem.Add(planiranoItemCol2);

            GridViewSummaryItem realiziranoItemCol0 = new GridViewSummaryItem();
            realiziranoItemCol0.Aggregate = GridAggregateFunction.Sum;
            realiziranoItemCol0.Name = "Column 0";

            GridViewSummaryItem realiziranoItemCol1 = new GridViewSummaryItem();
            realiziranoItemCol1.Aggregate = GridAggregateFunction.Sum;
            realiziranoItemCol1.Name = "Column 1";

            GridViewSummaryItem realiziranoItemCol2 = new GridViewSummaryItem();
            realiziranoItemCol2.Aggregate = GridAggregateFunction.Sum;
            realiziranoItemCol2.Name = "Column 2";

            GridViewSummaryRowItem realiziranoRowItem = new GridViewSummaryRowItem();
            realiziranoRowItem.Add(realiziranoItemCol0);
            realiziranoRowItem.Add(realiziranoItemCol1);
            realiziranoRowItem.Add(realiziranoItemCol2);

            this.radGridView1.SummaryRowsBottom.Add(planiranoRowItem);
            this.radGridView1.SummaryRowsBottom.Add(realiziranoRowItem);
        }

        private void radGridView1_ViewRowFormatting(object sender, RowFormattingEventArgs e)
        {
            if (!(e.RowElement.Data is GridViewSummaryRowInfo))
            {
                return;
            }

            if (((GridViewSummaryRowInfo)e.RowElement.Data).SummaryRowItem == this.radGridView1.SummaryRowsBottom[0])
            {
                e.RowElement.DrawFill = true;
                e.RowElement.BackColor = Color.CornflowerBlue;
                e.RowElement.BackColor2 = Color.Blue;
            }
            else if (((GridViewSummaryRowInfo)e.RowElement.Data).SummaryRowItem == this.radGridView1.SummaryRowsBottom[1])
            {
                e.RowElement.DrawFill = true;
                e.RowElement.BackColor = Color.Red;
                e.RowElement.BackColor2 = Color.DarkRed;
            }
            else
            {
                e.RowElement.ResetValue(LightVisualElement.DrawFillProperty, ValueResetFlags.Local);
                e.RowElement.ResetValue(LightVisualElement.BackColorProperty, ValueResetFlags.Local);
                e.RowElement.ResetValue(LightVisualElement.BackColor2Property, ValueResetFlags.Local);
            }
        }

        private void radGridView1_GroupSummaryEvaluate(object sender, GroupSummaryEvaluationEventArgs e)
        {
            if (e.SummaryItem != null)
            {
                if (((GridViewSummaryRowInfo)e.Context).SummaryRowItem == this.radGridView1.SummaryRowsBottom[0])
                {
                    e.Value = this.SumPlanirano(e.Parent, e.SummaryItem.Name);
                }
                else
                {
                    e.Value = this.SumRealizirano(e.Parent, e.SummaryItem.Name);
                }
            }
        }

        private decimal SumPlanirano(IHierarchicalRow row, string columnName)
        {
            decimal sum = 0;
            foreach (GridViewRowInfo childRow in row.ChildRows)
            {
                if (childRow.Index % 2 == 0)
                {
                    sum += (decimal)childRow.Cells[columnName].Value;
                }
            }

            return sum;
        }

        private decimal SumRealizirano(IHierarchicalRow row, string columnName)
        {
            decimal sum = 0;
            foreach (GridViewRowInfo childRow in row.ChildRows)
            {
                if (childRow.Index % 2 != 0)
                {
                    sum += (decimal)childRow.Cells[columnName].Value;
                }
            }

            return sum;
        }
    }
}
